import { useCallback, useEffect, useState } from "react";
import { userContext } from "@ess-ics/ce-ui-common";
import {
  useLoginMutation,
  useLogoutMutation,
  useInfoFromUserNameQuery,
  useGetUserRolesQuery
} from "../store/deployApi";

export function UserProvider({ children }) {
  const [user, setUser] = useState(null);
  const [userRoles, setUserRoles] = useState([]);

  const [
    callLogin,
    {
      data: loginResponse,
      error: loginError,
      isLoading: loginLoading,
      reset: resetLogin
    }
  ] = useLoginMutation();
  const [callLogout, { isLoading: logoutLoading }] = useLogoutMutation();
  const { data: userResponse, isLoading: userLoading } =
    useInfoFromUserNameQuery({
      skip: !loginResponse
    });
  const { data: userRolesResponse, isLoading: userRolesLoading } =
    useGetUserRolesQuery({ skip: !loginResponse });

  const initialized = Boolean(
    !loginLoading || !logoutLoading || !userLoading || !userRolesLoading
  );

  const login = useCallback(
    (username, password) => {
      callLogin({ login: { userName: username, password } });
    },
    [callLogin]
  );

  useEffect(() => {
    setUser(userResponse);
    setUserRoles(userRolesResponse);
  }, [userRolesResponse, userResponse]);

  const logout = useCallback(() => {
    callLogout();
    setUser(null);
    setUserRoles([]);
  }, [callLogout, setUser, setUserRoles]);

  return (
    initialized && (
      <userContext.Provider
        value={{
          user,
          userRoles,
          login,
          loginError: loginError?.data?.description,
          logout,
          resetLoginError: resetLogin
        }}
      >
        {children}
      </userContext.Provider>
    )
  );
}
