import { useCallback, useEffect } from "react";
import { Card, CardHeader } from "@mui/material";
import { usePagination } from "@ess-ics/ce-ui-common";
import { initRequestParams } from "../Helper";
import { JobTable } from "../../Job";
import {
  DEFAULT_POLLING_INTERVAL_MILLIS,
  ROWS_PER_PAGE
} from "../../../constants";
import { useLazyListJobsQuery } from "../../../store/deployApi";

export function UserOperationList({ userName }) {
  const [getJobs, { data: jobs, isFetching }] = useLazyListJobsQuery({
    pollingInterval: DEFAULT_POLLING_INTERVAL_MILLIS
  });

  const { pagination, setPagination } = usePagination({
    rowsPerPageOptions: ROWS_PER_PAGE,
    initLimit: ROWS_PER_PAGE[0],
    initPage: 0
  });

  // update pagination whenever search result total pages change
  useEffect(() => {
    setPagination({ totalCount: jobs?.totalCount ?? 0 });
  }, [setPagination, jobs?.totalCount]);

  const callGetjobs = useCallback(() => {
    const requestParams = initRequestParams(pagination);

    requestParams.user = userName;

    getJobs(requestParams);
  }, [getJobs, pagination, userName]);

  useEffect(() => {
    callGetjobs();
  }, [callGetjobs]);

  // Invoked by Table on change to pagination
  const onPage = (params) => {
    setPagination(params);
  };

  return (
    <Card variant="plain">
      <CardHeader
        title={"Jobs"}
        titleTypographyProps={{
          variant: "h2",
          component: "h2"
        }}
      />
      <JobTable
        jobs={jobs?.jobs}
        customColumns={[{ field: "status" }, { field: "job" }]}
        loading={isFetching || !jobs}
        pagination={pagination}
        onPage={onPage}
        rowType="userPageJobLog"
      />
    </Card>
  );
}
